==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/WorkspaceTagOperationLink.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [WorkspaceTagOperationLink].
 */
@PulumiTagMarker
public class WorkspaceTagOperationLinkResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WorkspaceTagOperationLinkArgs = WorkspaceTagOperationLinkArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WorkspaceTagOperationLinkArgsBuilder.() -> Unit) {
        val builder = WorkspaceTagOperationLinkArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): WorkspaceTagOperationLink {
        val builtJavaResource =
            com.pulumi.azurenative.apimanagement.WorkspaceTagOperationLink(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WorkspaceTagOperationLink(builtJavaResource)
    }
}

/**
 * Tag-operation link details.
 * Azure REST API version: 2022-09-01-preview.
 * Other available API versions: 2023-03-01-preview.
 * ## Example Usage
 * ### ApiManagementCreateWorkspaceTagOperationLink
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var workspaceTagOperationLink = new AzureNative.ApiManagement.WorkspaceTagOperationLink("workspaceTagOperationLink", new()
 *     {
 *         OperationId = "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.ApiManagement/service/apimService1/workspaces/wks1/apis/echo-api/operations/op1",
 *         OperationLinkId = "link1",
 *         ResourceGroupName = "rg1",
 *         ServiceName = "apimService1",
 *         TagId = "tag1",
 *         WorkspaceId = "wks1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/apimanagement/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := apimanagement.NewWorkspaceTagOperationLink(ctx, "workspaceTagOperationLink", &apimanagement.WorkspaceTagOperationLinkArgs{
 * 			OperationId:       pulumi.String("/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.ApiManagement/service/apimService1/workspaces/wks1/apis/echo-api/operations/op1"),
 * 			OperationLinkId:   pulumi.String("link1"),
 * 			ResourceGroupName: pulumi.String("rg1"),
 * 			ServiceName:       pulumi.String("apimService1"),
 * 			TagId:             pulumi.String("tag1"),
 * 			WorkspaceId:       pulumi.String("wks1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.apimanagement.WorkspaceTagOperationLink;
 * import com.pulumi.azurenative.apimanagement.WorkspaceTagOperationLinkArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var workspaceTagOperationLink = new WorkspaceTagOperationLink("workspaceTagOperationLink", WorkspaceTagOperationLinkArgs.builder()
 *             .operationId("/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.ApiManagement/service/apimService1/workspaces/wks1/apis/echo-api/operations/op1")
 *             .operationLinkId("link1")
 *             .resourceGroupName("rg1")
 *             .serviceName("apimService1")
 *             .tagId("tag1")
 *             .workspaceId("wks1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:apimanagement:WorkspaceTagOperationLink link1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ApiManagement/service/{serviceName}/workspaces/{workspaceId}/tags/{tagId}/operationLinks/{operationLinkId}
 * ```
 */
public class WorkspaceTagOperationLink internal constructor(
    override val javaResource: com.pulumi.azurenative.apimanagement.WorkspaceTagOperationLink,
) : KotlinCustomResource(javaResource, WorkspaceTagOperationLinkMapper) {
    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Full resource Id of an API operation.
     */
    public val operationId: Output<String>
        get() = javaResource.operationId().applyValue({ args0 -> args0 })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WorkspaceTagOperationLinkMapper : ResourceMapper<WorkspaceTagOperationLink> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.apimanagement.WorkspaceTagOperationLink::class == javaResource::class

    override fun map(javaResource: Resource): WorkspaceTagOperationLink =
        WorkspaceTagOperationLink(
            javaResource as
                com.pulumi.azurenative.apimanagement.WorkspaceTagOperationLink,
        )
}

/**
 * @see [WorkspaceTagOperationLink].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WorkspaceTagOperationLink].
 */
public suspend fun workspaceTagOperationLink(
    name: String,
    block: suspend WorkspaceTagOperationLinkResourceBuilder.() -> Unit,
): WorkspaceTagOperationLink {
    val builder = WorkspaceTagOperationLinkResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WorkspaceTagOperationLink].
 * @param name The _unique_ name of the resulting resource.
 */
public fun workspaceTagOperationLink(name: String): WorkspaceTagOperationLink {
    val builder = WorkspaceTagOperationLinkResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/WorkspaceTagOperationLink.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [WorkspaceTagOperationLink].
 */
@PulumiTagMarker
public class WorkspaceTagOperationLinkResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WorkspaceTagOperationLinkArgs = WorkspaceTagOperationLinkArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WorkspaceTagOperationLinkArgsBuilder.() -> Unit) {
        val builder = WorkspaceTagOperationLinkArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): WorkspaceTagOperationLink {
        val builtJavaResource =
            com.pulumi.azurenative.apimanagement.WorkspaceTagOperationLink(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WorkspaceTagOperationLink(builtJavaResource)
    }
}

/**
 * Tag-operation link details.
 * Azure REST API version: 2022-09-01-preview.
 * Other available API versions: 2023-03-01-preview, 2023-05-01-preview.
 * ## Example Usage
 * ### ApiManagementCreateWorkspaceTagOperationLink
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var workspaceTagOperationLink = new AzureNative.ApiManagement.WorkspaceTagOperationLink("workspaceTagOperationLink", new()
 *     {
 *         OperationId = "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.ApiManagement/service/apimService1/workspaces/wks1/apis/echo-api/operations/op1",
 *         OperationLinkId = "link1",
 *         ResourceGroupName = "rg1",
 *         ServiceName = "apimService1",
 *         TagId = "tag1",
 *         WorkspaceId = "wks1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/apimanagement/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := apimanagement.NewWorkspaceTagOperationLink(ctx, "workspaceTagOperationLink", &apimanagement.WorkspaceTagOperationLinkArgs{
 * 			OperationId:       pulumi.String("/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.ApiManagement/service/apimService1/workspaces/wks1/apis/echo-api/operations/op1"),
 * 			OperationLinkId:   pulumi.String("link1"),
 * 			ResourceGroupName: pulumi.String("rg1"),
 * 			ServiceName:       pulumi.String("apimService1"),
 * 			TagId:             pulumi.String("tag1"),
 * 			WorkspaceId:       pulumi.String("wks1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.apimanagement.WorkspaceTagOperationLink;
 * import com.pulumi.azurenative.apimanagement.WorkspaceTagOperationLinkArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var workspaceTagOperationLink = new WorkspaceTagOperationLink("workspaceTagOperationLink", WorkspaceTagOperationLinkArgs.builder()
 *             .operationId("/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.ApiManagement/service/apimService1/workspaces/wks1/apis/echo-api/operations/op1")
 *             .operationLinkId("link1")
 *             .resourceGroupName("rg1")
 *             .serviceName("apimService1")
 *             .tagId("tag1")
 *             .workspaceId("wks1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:apimanagement:WorkspaceTagOperationLink link1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ApiManagement/service/{serviceName}/workspaces/{workspaceId}/tags/{tagId}/operationLinks/{operationLinkId}
 * ```
 */
public class WorkspaceTagOperationLink internal constructor(
    override val javaResource: com.pulumi.azurenative.apimanagement.WorkspaceTagOperationLink,
) : KotlinCustomResource(javaResource, WorkspaceTagOperationLinkMapper) {
    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Full resource Id of an API operation.
     */
    public val operationId: Output<String>
        get() = javaResource.operationId().applyValue({ args0 -> args0 })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WorkspaceTagOperationLinkMapper : ResourceMapper<WorkspaceTagOperationLink> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.apimanagement.WorkspaceTagOperationLink::class == javaResource::class

    override fun map(javaResource: Resource): WorkspaceTagOperationLink =
        WorkspaceTagOperationLink(
            javaResource as
                com.pulumi.azurenative.apimanagement.WorkspaceTagOperationLink,
        )
}

/**
 * @see [WorkspaceTagOperationLink].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WorkspaceTagOperationLink].
 */
public suspend fun workspaceTagOperationLink(
    name: String,
    block: suspend WorkspaceTagOperationLinkResourceBuilder.() -> Unit,
): WorkspaceTagOperationLink {
    val builder = WorkspaceTagOperationLinkResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WorkspaceTagOperationLink].
 * @param name The _unique_ name of the resulting resource.
 */
public fun workspaceTagOperationLink(name: String): WorkspaceTagOperationLink {
    val builder = WorkspaceTagOperationLinkResourceBuilder()
    builder.name(name)
    return builder.build()
}
